==> veriloggen-1.9.9.tar.gz: veriloggen-1.9.9/tests/extension/types_/mul_/with_all/types_mul_with_all.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os
import math

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))))))

from veriloggen import *
import veriloggen.types.mul as mul


def mkMain(n=128, datawidth=32, numports=2):
    m = Module('main')

    clk = m.Input('CLK')
    rst = m.Input('RST')

    a = m.Reg('a', 16, initval=0)
    b = m.Reg('b', 16, initval=0)
    c = m.Wire('c', a.bit_length() + b.bit_length())

    enable = m.Reg('enable', initval=0)
    update = m.Reg('update', initval=0)

    mymul = mul.Multiplier(m, 'mymul', clk, rst, a, b, enable, update)

    seq = Seq(m, 'seq', clk, rst)

    seq.If(Not(update))(
        a.add(1),
        b.add(1),
        enable(Not(enable))
    )

    seq(
        update(Not(update))
    )

    seq.If(mymul.valid)(
        Display("mymul.value = %d", mymul.value)
    )

    return m


def mkTest():
    m = Module('test')

    # target instance
    main = mkMain()

    # copy paras and ports
    params = m.copy_params(main)
    ports = m.copy_sim_ports(main)

    clk = ports['CLK']
    rst = ports['RST']

    uut = m.Instance(main, 'uut',
                     params=m.connect_params(main),
                     ports=m.connect_ports(main))

    simulation.setup_waveform(m, uut, m.get_vars())
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(1000),
        Systask('finish'),
    )

    return m

if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog('tmp.v')
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)

    # sim.view_waveform()

==> veriloggen-2.0.2.tar.gz: veriloggen-2.0.2/tests/extension/types_/mul_/with_all/types_mul_with_all.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os
import math

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))))))

from veriloggen import *
import veriloggen.types.mul as mul


def mkMain(n=128, datawidth=32, numports=2):
    m = Module('main')

    clk = m.Input('CLK')
    rst = m.Input('RST')

    a = m.Reg('a', 16, initval=0)
    b = m.Reg('b', 16, initval=0)
    c = m.Wire('c', a.bit_length() + b.bit_length())

    enable = m.Reg('enable', initval=0)
    update = m.Reg('update', initval=0)

    mymul = mul.Multiplier(m, 'mymul', clk, rst, a, b, enable, update)

    seq = Seq(m, 'seq', clk, rst)

    seq.If(Not(update))(
        a.add(1),
        b.add(1),
        enable(Not(enable))
    )

    seq(
        update(Not(update))
    )

    seq.If(mymul.valid)(
        Display("mymul.value = %d", mymul.value)
    )

    return m


def mkTest():
    m = Module('test')

    # target instance
    main = mkMain()

    # copy paras and ports
    params = m.copy_params(main)
    ports = m.copy_sim_ports(main)

    clk = ports['CLK']
    rst = ports['RST']

    uut = m.Instance(main, 'uut',
                     params=m.connect_params(main),
                     ports=m.connect_ports(main))

    # simulation.setup_waveform(m, uut, m.get_vars())
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(1000),
        Systask('finish'),
    )

    return m


if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog('tmp.v')
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)

    # sim.view_waveform()
